<?php
/**
 * Teller functions and definitions
 *
 * @package Teller
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

if ( ! function_exists( 'teller_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function teller_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Teller, use a find and replace
	 * to change 'teller' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'teller', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	add_image_size( 'port-thumb', 614, 9999);
	add_image_size( 'blog', 980, 475, array('center', 'center'));
	add_image_size( 'blog-recent', 430, 287, array('center', 'center'));

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'teller' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );
}
endif; // teller_setup
add_action( 'after_setup_theme', 'teller_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function teller_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'teller' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'teller_widgets_init' );

/**
 * Enqueue scripts and styles.
 */

function teller_fonts_url() {
    $fonts_url = '';
 
    $font_families[] = 'Lora:400,700,400italic,700italic';

    $font_families[] = 'Open Sans Condensed:300,700,300italic';

 
    $query_args = array(
        'family' => urlencode( implode( '|', $font_families ) ),
        'subset' => urlencode( 'latin,latin-ext' ),
    );
 
    $fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );
 
    return $fonts_url;
}

function teller_admin_scripts() {

	// Admin Styles
	
  	wp_enqueue_style('custom-admin-styles', get_template_directory_uri() . '/css/admin.css');

}

add_action( 'admin_enqueue_scripts', 'teller_admin_scripts' );

function teller_scripts() {
	wp_enqueue_style( 'teller-style', get_stylesheet_uri() );

	wp_enqueue_style( 'magnific-css', get_template_directory_uri().'/css/magnific-popup.css' ) ;

	wp_enqueue_style( 'teller-fonts', teller_fonts_url(), array(), null );

	wp_enqueue_script ('jquery');

	wp_enqueue_script( 'imagesloaded', get_template_directory_uri() . '/js/imagesloaded.pkgd.min.js', array(), '', true );

	wp_enqueue_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array(), '', true );

	wp_enqueue_script( 'masonry', get_template_directory_uri() . '/js/masonry.pkgd.min.js', array(), '', true );

	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/js/jquery.fitvids.js', array(), '', true );

	wp_enqueue_script( 'lightbox', get_template_directory_uri() . '/js/jquery.magnific-popup.min.js', array(), '', true );

	wp_enqueue_script( 'teller-scripts', get_template_directory_uri() . '/js/scripts.js', array(), '', true );


	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'teller_scripts' );

/**
 * Implement the Custom Header feature.
 */
//require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom post types for this theme.
 */
require get_template_directory() . '/inc/custom-post-types.php';

/**
 * Custom meta boxes for this theme.
 */
require get_template_directory() . '/inc/custom-meta-boxes.php';

/**
 * Custom shortcodes for this theme.
 */
require get_template_directory() . '/inc/custom-shortcodes.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

/**
 * SMOF
 */
require get_template_directory() . '/admin/index.php';

/**
 * Require Plugins
 */
require_once ('inc/class-tgm-plugin-activation.php');