<?php

/*
 * Teller Custom Meta Boxes
 */



// Add Meta Boxes

function teller_custom_meta() {

    // Page Header

    add_meta_box( 'page_header', __( 'Header Style', 'teller' ), 'page_header', 'page', 'normal', 'high' );

    add_meta_box( 'page_subtitle', __( 'Full Header Options', 'teller' ), 'subtitle', 'page', 'normal', 'high' );


    // Portfolio Dispaly Boxes

    add_meta_box( 'portfolio_sc', __( 'Portfolio Display Shortcode', 'teller' ), 'portfolio_display_sc', 'port_display', 'side', 'high' );

    add_meta_box( 'portfolio_display', __( 'Portfolio Display', 'teller' ), 'portfolio_display', 'port_display', 'normal', 'high' );


}

add_action( 'add_meta_boxes', 'teller_custom_meta' );



// Display Subtitle Box

function subtitle( $post ) {

    wp_nonce_field( basename( __FILE__ ), 'teller_nonce' );
    $teller_stored_meta = get_post_meta( $post->ID );
    ?>

    <div class="meta-content">
        <label for="subtitle">Subtitle</label>
        <input type="text" name="subtitle" value="<?php if ( isset ( $teller_stored_meta['subtitle'] ) ) echo $teller_stored_meta['subtitle'][0]; ?>" />
        <label for="description">Description</label>
        <textarea name="description" rows="5" cols="80"><?php if ( isset ( $teller_stored_meta['description'] ) ) echo $teller_stored_meta['description'][0]; ?></textarea>
        <label for="button">Button</label>
        <select name="button" id="button">
            <option value="1" <?php if ( isset ( $teller_stored_meta['button'] ) && $teller_stored_meta['button'][0] == '1' ) { echo 'selected';} ?>>No</option>
            <option value="2" <?php if ( isset ( $teller_stored_meta['button'] ) && $teller_stored_meta['button'][0] == '2' ) { echo 'selected';} ?>>Yes</option>
        </select>
        <label for="button-url">Button Url</label>
        <input type="text" name="button-url" value="<?php if ( isset ( $teller_stored_meta['button-url'] ) ) echo $teller_stored_meta['button-url'][0]; ?>" />
        <label for="button-url">Button Text</label>
        <input type="text" name="button-text" value="<?php if ( isset ( $teller_stored_meta['button-text'] ) ) echo $teller_stored_meta['button-text'][0]; ?>" />
    </div>


<?php }



// Page Header

function page_header( $post ) {

    wp_nonce_field( basename( __FILE__ ), 'teller_nonce' );
    $teller_stored_meta = get_post_meta( $post->ID );
    ?>

    <div class="meta-content">
        <select name="page-header" id="page-header">
            <option value="1" <?php if ( isset ( $teller_stored_meta['page-header'] ) && $teller_stored_meta['page-header'][0] == '1' ) { echo 'selected';} ?>>Minimal</option>
            <option value="2" <?php if ( isset ( $teller_stored_meta['page-header'] ) && $teller_stored_meta['page-header'][0] == '2' ) { echo 'selected';} ?>>Full Image Header</option>
        </select>
    </div>

<?php }


// Portfolio Display

function portfolio_display( $post ) {

    wp_nonce_field( basename( __FILE__ ), 'teller_nonce' );
    $teller_stored_meta = get_post_meta( $post->ID );
    $teller_stored_cats = get_post_meta( $post->ID, 'item-cats' );
    ?>
    
    <div class="meta-content">

        <label for="item-limit">Item Limit</label>
        <input type="text" name="item-limit" id="item-limit" value="<?php if ( isset ( $teller_stored_meta['item-limit'] ) ) echo $teller_stored_meta['item-limit'][0]; ?>">

        <br>

        <label for="item-ids">Portfolio Item IDs separated by a comma and space. Example: 1, 23, 33</label>
        <input type="text" name="item-ids" id="item-ids" value="<?php if ( isset ( $teller_stored_meta['item-ids'] ) ) echo $teller_stored_meta['item-ids'][0]; ?>">

        <br>
        <br>

        <label for="item-cats">Categories to Display</label>
        <br>

        <?php

        echo '<input type="checkbox" value="" style="display:none;" name="item-cats[]" checked="checked">';

        $terms = get_terms("port-cat");
         if ( !empty( $terms ) && !is_wp_error( $terms ) ){
            $i = 0; 
             foreach ( $terms as $term ) {
               echo "<input type='checkbox' name='item-cats[]' value='" . $term->slug . "' ";
               if (is_array($teller_stored_cats[0]) && in_array($term->slug, $teller_stored_cats[0])) {
                echo 'checked="checked"';
               }
               echo " > " . $term->name . " </br>";
               $i++;
             }
         }

         ?>

     </div>

<?php }

function portfolio_display_sc( $post ) {

    echo '[port_display id="' . $post->ID . '"]';

}


// Save Meta Boxes

function teller_meta_save( $post_id ) {
 
    // Checks save status
    $is_autosave = wp_is_post_autosave( $post_id );
    $is_revision = wp_is_post_revision( $post_id );
    $is_valid_nonce = ( isset( $_POST[ 'teller_nonce' ] ) && wp_verify_nonce( $_POST[ 'teller_nonce' ], basename( __FILE__ ) ) ) ? 'true' : 'false';
 
    // Exits script depending on save status

    if ( $is_autosave || $is_revision || !$is_valid_nonce ) {
        return;
    }


    // Checks for input and sanitizes/saves if needed


    // Page Header

    if( isset( $_POST[ 'page-header' ] ) ) {
        update_post_meta( $post_id, 'page-header', $_POST[ 'page-header' ] );
    }

    if( isset( $_POST[ 'subtitle' ] ) ) {
        update_post_meta( $post_id, 'subtitle', sanitize_text_field( $_POST[ 'subtitle' ] ) );
    }

    if( isset( $_POST[ 'description' ] ) ) {
        update_post_meta( $post_id, 'description', sanitize_text_field( $_POST[ 'description' ] ) );
    }

    if( isset( $_POST[ 'button' ] ) ) {
        update_post_meta( $post_id, 'button', $_POST[ 'button' ] );
    }

    if( isset( $_POST[ 'button-url' ] ) ) {
        update_post_meta( $post_id, 'button-url', $_POST[ 'button-url' ] );
    }

    if( isset( $_POST[ 'button-text' ] ) ) {
        update_post_meta( $post_id, 'button-text', $_POST[ 'button-text' ] );
    }


    // Portfolio Display Input

    if( isset( $_POST[ 'port-page-display' ] ) ) {
        update_post_meta( $post_id, 'port-page-display', sanitize_text_field($_POST[ 'port-page-display' ] ) );
    } 

    if( isset( $_POST[ 'port-type' ] ) ) {
        update_post_meta( $post_id, 'port-type', $_POST[ 'port-type' ] );
    }

    if( isset( $_POST[ 'item-ids' ] ) ) {
        update_post_meta( $post_id, 'item-ids', $_POST[ 'item-ids' ] );
    }

    if( isset( $_POST[ 'item-cats' ] ) ) {
        update_post_meta( $post_id, 'item-cats', $_POST[ 'item-cats' ] );
    }

    if( isset( $_POST[ 'row-size' ] ) ) {
        update_post_meta( $post_id, 'row-size', $_POST[ 'row-size' ] );
    }

    if( isset( $_POST[ 'item-limit' ] ) ) {
        update_post_meta( $post_id, 'item-limit', $_POST[ 'item-limit' ] );
    }


 
}

add_action( 'save_post', 'teller_meta_save' );